from .core import create_note, open_note, list_notes
from .config import Config
from .paths import NOTES_PATH
import json
from argparse import ArgumentParser
from uuid import uuid4

new_id = str(uuid4())

def main():
    parser = ArgumentParser(usage='pystickynote <open/create/list> <name/all>')
    parser.add_argument('action', choices=['open', 'create', 'list'], help='Action to run. Either "open" or "create".')
    parser.add_argument('name', help='Stickynote\'s name to save to', nargs='?', default=new_id)
    args = parser.parse_args()
    config = Config()
    if args.action == 'create':
        if args.name == new_id:
            print('Please Provide A Name for Your Note.')
        else:
            with open(NOTES_PATH, 'r+') as json_file:
                obj = json.load(json_file)
                for k, v in obj.items():
                    if args.name == k:
                        print('Note with that name found, please use the open command to edit/delete.')
                        exit(1)
            create_note(args.name, config)
    elif args.action == 'open':
        if args.name == new_id:
            print('Please Provide The Name of The Note.')
        else:
            open_note(args.name, config)
    elif args.action == 'list':
        list_notes()
    exit(0)

if __name__ == "__main__":
    main()


from pystickynote.paths import NOTES_PATH
import PySimpleGUIQt as g
import sys
import json

if 'darwin' in sys.platform:
    NTB = False
else:
    NTB = True

def open_note(name, config):
    g.SetOptions(background_color=config.background_color, text_color=config.text_color,
                 input_elements_background_color=config.background_color, input_text_color=config.text_color,
                 button_color=(config.text_color, config.background_color), border_width=config.border_width, font=('Arial', int(config.font_size)))
    with open(NOTES_PATH, 'r+') as notes:
        note_obj = json.load(notes)
        match = False
        content = ''
    for k, v in note_obj.items():
        if name == k:
            match = True
            content = v
    if match == False:
        print('No Note Found With That Name')
        exit(1)
    layout = [
        [g.T(name, font=('Arial', int(config.title_size)), justification='center')],
        [g.Multiline(content, size=(50, 5), key='content')],
        [g.B('Close'), g.B('Delete'), g.B('Save')]
    ]
    
    window = g.Window('Create', no_titlebar=NTB, keep_on_top=True, grab_anywhere=True, layout=layout, alpha_channel=float(config.alpha))
    
    while True:
        event, value = window.Read()
        if event == 'Close':
            window.Close()
            break
        elif event == 'Save':
            note_obj[name] = value['content']
            with open(NOTES_PATH, 'r+') as notes:
                notes.seek(0)
                notes.truncate()
                json.dump(note_obj, notes, indent=4)
            window.Close()
            break
        elif event == 'Delete':
            new_layout = [
                [g.T('Are you sure you want to delete {}?'.format(name), justification='center')],
                [g.B('No'), g.B('Yes')]
            ]
            confirm_window = g.Window('', no_titlebar=NTB, keep_on_top=True, grab_anywhere=True, layout=new_layout)
            while True:
                event1, value1 = confirm_window.Read()
                if event1 == 'Yes':
                    note_obj.pop(name, [])
                    with open(NOTES_PATH, 'r+') as notes:
                        notes.seek(0)
                        notes.truncate()
                        json.dump(note_obj, notes, indent=4)
                    confirm_window.Close()
                    break
                else:
                    confirm_window.Close()
                    break
            window.Close()
            break
                
def create_note(name, config):
    g.SetOptions(background_color=config.background_color, text_color=config.text_color,
                 input_elements_background_color=config.background_color, input_text_color=config.text_color,
                 button_color=(config.text_color, config.background_color), border_width=config.border_width, font=('Arial', int(config.font_size)))
    layout = [
        [g.T('Create Note', font=('Arial', int(config.title_size)), justification='center')],
        [g.Multiline('', size=(50, 5), key='content')],
        [g.B('Close'), g.B('Save')]
    ]
    window = g.Window('Create', no_titlebar=NTB, keep_on_top=True, grab_anywhere=True, layout=layout, alpha_channel=float(config.alpha))
    while True:
        event, value = window.Read()
        if event == 'Close':
            window.Close()
            break
        elif event == 'Save':
            with open(NOTES_PATH, 'r+') as notes:
                note_obj = json.load(notes)
                note_obj.update({
                    name: value['content']
                })
                notes.seek(0)
                notes.truncate()
                json.dump(note_obj, notes, indent=4)
            window.Close()
            break
        
def list_notes():
    with open(NOTES_PATH, 'r+') as json_file:
        obj = json.load(json_file)
        print('Available Notes:\n')
        for k, v in obj.items():
            print(k)


from pystickynote.paths import CONFIG_PATH, NOTES_PATH, PATH_DIR
from configparser import ConfigParser
import os

example_config = """\
[DEFAULT]
background_color = #454545
text_color = #fafafa
alpha = 0.8
border_width = 0
title_size = 8
font_size = 10"""

class Config:
    def __init__(self):
        self.config = ConfigParser()
        if not os.path.exists(PATH_DIR):
            os.makedirs(PATH_DIR)
        if not os.path.exists(CONFIG_PATH):
            with open(CONFIG_PATH, 'w') as file:
                file.write(example_config)
        if not os.path.exists(NOTES_PATH):
            with open(NOTES_PATH, 'w') as file:
                file.write('{}')
        self.config.read(CONFIG_PATH)
        self.config_dict = self.config['DEFAULT']
        self.background_color = self.config_dict['background_color']
        self.text_color = self.config_dict['text_color']
        self.alpha = self.config_dict['alpha']
        self.border_width = self.config_dict['border_width']
        self.font_size = self.config_dict['font_size']
        self.title_size = self.config_dict['title_size']


import os

CONFIG_PATH = os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote/pysn.conf')
NOTES_PATH = os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote/notes.json')
PATH_DIR = os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote/')
